API docs for “spamfighter.core.null_partner.NullPartner”

# Class s.c.n.NullPartner(object):

Part of spamfighter.core.null_partner View Source View In Hierarchy

Партнер, авторизованный без логина/пароля (на доверии).

Instance Variables | domain | корневой домен партнера (type: `BaseDomain` )

Method | __init__ | Конструктор.
Method | rootDomain | Получить корневой домен партнера.

def __init__(self): (source)
Конструктор.

def rootDomain(self): (source)
Получить корневой домен партнера.

Returns | Deferred, корневой домен (`IDomain`) (type: `twisted.internet.defer.Deferred` )